@@ -3,13 +3,15 @@ Main interface for workmailmessageflow service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workmailmessageflow import WorkMailMessageFlowClient
+    from mypy_boto3_workmailmessageflow import WorkMailMessageFlowClient
 
     session = boto3.Session()
 
     client: WorkMailMessageFlowClient = boto3.client("workmailmessageflow")
     session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, TYPE_CHECKING, Type
